A code generator for state machines with an entry API.
See the fsmentry crate.
Macros
- dot
- Generates a state machine from the
DOTgraph description language: - dsl
- Generates a state machine from the following language:
A code generator for state machines with an entry API.
See the fsmentry crate.
DOT graph description language: